@@ -15,7 +15,8 @@ from datetime import datetime
 from magicapi.Utils.random_utils import random_str
 from magicapi.Errors import BackendException
 
-from magicapi import settings
+# from magicapi import settings
+from magicapi import g
 
 from magicapi.Decorators.helpers import async_safe
 
@@ -31,7 +32,7 @@ def run_in_background(f):
         secret_token: str = Body(...),
         params: str = Body(...),
     ):
-        if settings.print_level > 1:
+        if g.settings.print_level > 1:
             print("endpoint just received!", "params", params)
         # get the task from dynamo
         response = Task.get_table().get_item(Key={"task_id": task_id})
@@ -53,7 +54,7 @@ def run_in_background(f):
         j_params = json.loads(params)
         args = j_params.get("args", [])
         kwargs = j_params.get("kwargs", {})
-        if settings.print_level > 1:
+        if g.settings.print_level > 1:
             print("inspect", inspect.signature(f), "a", args, "k", kwargs)
 
         await async_safe(f, *args, **kwargs)
@@ -69,7 +70,7 @@ def run_in_background(f):
                 message="You cannot add tasks if you do not add a DB!"
             )
 
-        if settings.print_level > 1:
+        if g.settings.print_level > 1:
             print("given to function", "args", args, "kwargs", kwargs)
         task_params = TaskParams(args=list(args), kwargs=kwargs)
         now = datetime.utcnow()
@@ -82,7 +83,7 @@ def run_in_background(f):
             created_at=now,
             last_updated=now,
             params=task_params.json(),
-            local=settings.local,
+            local=g.settings.local,
         )
         g.tasks.append(task)
 
