@@ -12,8 +12,8 @@ from magicapi.Utils.random_utils import random_str
 from magicapi.Decorators.background_tasks import run_in_background
 from magicapi.Decorators.parse_objects import parse_objects
 
-from magicapi import settings
-
+# from magicapi import settings
+from magicapi import g
 
 class Error(BaseModel):
     error_class: str
@@ -84,7 +84,7 @@ async def get_request_body(request: FastAPIRequest):
     except Exception as body_error:
         errors.append(f"body_error {body_error}")
 
-    if settings.print_level > 1:
+    if g.settings.print_level > 1:
         print("get_request_body_errors", errors)
 
     return None
@@ -129,7 +129,7 @@ async def make_call_from_request_and_response(
     error: Optional[Exception],
     times_dict: dict,
 ):
-    if not settings.save_calls:
+    if not g.settings.save_calls:
         return
 
     body = await get_request_body(request)
