@@ -14,18 +14,19 @@ from .errors import DoormanAuthException
 from magicapi.Decorators.firestore import need_firestore
 from magicapi.FieldTypes import PhoneNumber
 
-from magicapi import settings
+# from magicapi import settings
+from magicapi import g
 
 LOCATION, PROJECT_ID, DOORMAN_ID = (
-    settings.cloud_function_location or "us-central1",
-    settings.firebase_project_id,
-    settings.doorman_public_project_id,
+    g.settings.cloud_function_location or "us-central1",
+    g.settings.firebase_project_id,
+    g.settings.doorman_public_project_id,
 )
 
 ID_TOKEN_ENDPOINT: str = f"https://{LOCATION}-{PROJECT_ID}.cloudfunctions.net/getIdToken"
 DOORMAN_BACKEND_ENDPOINT: str = "https://sending-messages-for-doorman.herokuapp.com/phoneLogic"
 
-token_url = "/token" if settings.local else f"/{settings.stage}/token"
+token_url = "/token" if g.settings.local else f"/{g.settings.stage}/token"
 oath2_scheme = OAuth2PasswordBearer(tokenUrl=token_url)
 
 
