@@ -1,10 +1,11 @@
 import analytics
 
-from magicapi import settings
+# from magicapi import settings
+from magicapi import g
 
 from magicapi.Decorators.background_tasks import run_in_background
 
-analytics.write_key = settings.segment_write_key
+analytics.write_key = g.settings.segment_write_key
 analytics.sync_mode = True
 
 
