@@ -9,10 +9,13 @@ from mangum import Mangum
 from fastapi import FastAPI, Request, APIRouter
 from fastapi.middleware.cors import CORSMiddleware
 
-from .config import settings
+# from .config import settings
+from .config import MagicSettings, config_firestore
 
 from magicapi.Globals.G import g
 
+from pydantic import BaseSettings
+
 
 def add_cors(new_app):
     new_app.add_middleware(
@@ -25,6 +28,8 @@ def add_cors(new_app):
 
 
 def add_tasks_and_process_time_middleware(new_app):
+    from magicapi.Models.task_executor import save_tasks
+
     @new_app.middleware("http")
     async def add_process_time_and_tasks(request: Request, call_next):
         start_time = time.time()
@@ -32,7 +37,9 @@ def add_tasks_and_process_time_middleware(new_app):
         g.app = new_app
         print("url path", request.url.path, "***url", request.url)
         response = await call_next(request)
-        response.headers["X-Tasks-Time"] = str(g.save_tasks())  # queue tasks
+        # response.headers["X-Tasks-Time"] = str(g.save_tasks())  # queue tasks
+        response.headers["X-Tasks-Time"] = str(save_tasks())  # queue tasks
+
         response.headers["X-Process-Time"] = str(time.time() - start_time)
         return response
 
@@ -68,7 +75,8 @@ def add_magic_routers():
     g.app.include_router(g.magic_router)
 
 
-def create_app(config_settings=settings):
+def create_app(config_settings=MagicSettings()):
+    g.settings = config_settings
     print("creating_app", datetime.datetime.now())
     new_app = FastAPI(
         title=config_settings.app_name,
@@ -80,6 +88,9 @@ def create_app(config_settings=settings):
     g.app = new_app
     add_background_tasks()
     make_magic_router(g.app)
+
+    config_firestore(g.settings.service_account_name)
+
     return new_app
 
 
